How To - Schritt für Schritt Anleitung — excel2moodle 0.3.4 documentation

# How To - Schritt für Schritt Anleitung

In dieser How-To Anleitung werden unterschiedliche Arbeiten mit dem Excel2moodle Schritt für Schritt gezeigt. Die folgenden Prozesse sind dokumentiert

Die folgenden Prozesse sind noch nicht dokumentiert:

> - Fragen in der Tabellenkalkulation erstellen

Auch wenn manche Arbeitsschritte noch nicht als How-To dargestellt sind, lassen sich die wichtigsten Informationen zur Vorgehensweise im User Guide auf Englisch finden.

## Excel2moodle unter Windows installieren

excel2moodle ist ein Python Paket und im Python Packaging Index [ Pypi.org ]( https://pypi.org/project/excel2moodle/ ) verfügbar und über den Paketmanager von Python installierbar. Voraussetzung für die Installation von excel2moodle ist daher eine Python Installation.

Um excel2moodle nutzten zu können sind die folgenden Schritte Notwendig

### 1. Installation von Python

Der Python Interpreter kann über den Microsoft Store installiert werden. Über die PowerShell geht das wie folgt:

    winget python

Es ist die Version python 3.13 empfohlen.

Note

Alternativ kann der Python Interpreter über [python.org/downloas/winows](https://www.python.org/downloads/windows/) heruntergeladen und dann die python3.XX.XX.exe installiert werden Wichtig ist, während der Installation den Haken bei Add python.exe to PATH zu setzen.

Sobald Python installiert ist, kann es in der PowerShell aufgerufen werden mit einem (oder mehreren) der folgenden Befehle:

- py (Nach der Installation über den offiziellen Python-Installer)

- python

- python3 (Nach der Installation über den Microsoft Store)

Note

Im folgenden wird immer der Befehl py verwendet. Der kann wenn notwendig mit python3 ersetzt werden.

### 2. Installation von pipx

Es ist sehr zu empfehlen excel2moodle über den Paketmanager pipx zu installieren, da dies sicherstellt, dass die Abhängigkeiten von excel2moodle nicht mit Abhängigkeiten von anderen python Paketen kollidieren. Daher Muss zunächs Paketmanager pipx installiert werden, der dann excel2moodle in eine isolierte Umgebung installiert.

In der PowerShell folgendes ausführen:

    py -m pip install --user pipx

Vermutlich wird die installation mit der folgenden Warnung enden:

    WARNING: The script pipx.exe is installed in `<USER folder>\AppData\Roaming\Python\Python3x\Scripts` which is not on PATH

Das bedeutet, dass pipx nicht direkt ausführbar ist, weil es nicht in der PATH variable gelistet ist. Um pipx zu PATH hinzuzufügen folgendes ausführen:

    py -m pipx ensurepath

Nach einem neustart der PowerShell lässt sich pipx direkt ausführen.

Note

Updates von pipx selbst können mit: py -m pip install –user –upgrade pipx installiert werden.

### 3. Installation von excel2moodle

Mit pipx kann nun excel2moodle installiert werden.

In der PowerShell folgendes ausführen:

    pipx install excel2moodle

Note

Wenn ein neues Update von excel2moodle installiert werden soll, ist die möglich mit: pipx upgrade excel2moodle

### 4. Starten von excel2moodle

Sobald excel2moodle über pipx installiert ist, kann es direkt ausgeführt werden.

Hierfür wieder eine PowerShell oder CMD öffnen und den folgenden Befehl ausführen:

    excel2moodle

## Export einer Fragen-Auswahl aus Excel2moodle

Um Fragen aus excel2moodle zu exportieren und für den Impot in Moodle vorzubereiten sind die Folgenden Schritte notwendig:

1. Auswahl der gewünschten Fragen durch anklicken: Wenn alle oder keine Fragen ausgewählt werden sollen, kann über der Fragenliste der Haken bei select all gesetzt, bzw. zurückgesetzt werden.

2. Überprüfen ob die Anzahl an Fragen und Gesamtpunkten richtig ist. Dies ist möglich oben rechts neben der Fragenliste im Bereich Selection

3. Expot Einstellungen wählen: Die folgenden Einstellungen sollten vor dem Export eingestellt werden. Excel2moodle merkt sich diese Einstellungen und übernimmt immer jene der letzten Sitzung Die Einstellungen werden unten rechts neben der Fragenliste gewählt, siehe :ref: imgExportAuswahl

   - Fragenvariante für NFM Fragen wählen:

       Für den Fragentyp `NFM` werden mehrere Versionen der gleichen Numerischen Frage erstellt. In der Fragenliste wird jedoch nur eine Frage gelistet. Daher wird erst beim Export die Variante gewählt. Um nicht bei jeder Frage nachfragen zu müssen, kann eine standard Variante gewählt werden (Bsp. nr. 3). Wenn bei einer Frage es keine Vesion 3 gibt, wird nur bei dieser nachgefragt. Wenn keine Fragenvariante gewählt wird, bzw. Variante 0 gewählt ist, wird beim Export jeder einzelnen Frage ein dialog angezeigt zur Auswahl der Frage

   - Fragen kategorisiert exportieren:

       Excel2moodle bietet die Möglichkeit die Fragen kategorisiert zu exportieren oder nicht. Wenn die Fragen kategorisiert exportiert werden, werden diese in Moodle in den Kategorien einsortiert, wie sie auch in der Tabellenkalkulation sortiet sind. ( Wenn diese Kategorien in dem Moodle-Test nicht existieren, werden sie automatisch erstellt. )

Export der Fragenauswahl aus Excel2moodle

In Excel2moodle sind alle Fragen ausgewählt über die Checkbox über der Fragenliste. Rechts sieht man die Anzahl an gewählten Fragen und die Summe der Punkte, die alle Fragen bei richtiger Beantwortung ergeben. Rechts unten ist ausgewählt `Include Questions in Categories` das bedeutet, dass die Kategorien auch exportiert werden und in Moodle die Fragen dann kategorisiert bleiben. Ist dieser Haken nicht gesetzt, werden alle Fragen in die vormals im Moodle ausgewählte Kategorie importiert.

## Import einer Fragensammlung in Moodle

Um eine Fragen Auswahl, die zuvor mit Excel2moodle erstellt wurde in Moodle zu importieren, sind die folgenden Schritte notwendig:

1. In dem Test-Element im Moodlekurs wird zu dem Reiter Fragensammlung navigiert.

2. Dort wird in dem Dropdown-Menu Oben Recht die Option `Import` ausgewählt.

3. Der Import-Typ muss `Moodle-xml` sein

4. Nun kann die Datei `*.xml` ausgewählt werden.

   Die Import Übersichtsseite im Moodle. Von Oben nach Unten müssen alle Gelb markierten Stellen ausgewählt werden

5. Nachdem der `Import` Button geklickt wurde, erscheint eine Übersicht über die importierten Fragen.

   Die Übersicht über alle importieren Fragen. Etwaige Fehler werden hier auch angezeigt

6. Wenn der Import in Moodle erfolgreich war, ist zu sehen, dass alle Fragen, die in dem How-to Export einer Fragen-Auswahl aus Excel2moodle (zu sehen in Export der Fragenauswahl aus Excel2moodle) exportiert wurden nun in Moodle verfügbar sind. Die Fragen sind einsortiert in die Kategorien KAT_01 und KAT_02

   Die Übersicht über die Fragenkategorien in Moodle. Die Kategorien KAT_01 und KAT_02 wurden automatisch beim Import erstellt. In Klammern hinter den Kategorien Namen sind die Anzahl an Fragen.

Note

Der Import erfolgt bei Moodle immer in die zuletzt ausgewählte Kategorie, wenn in der `*.xml` Datei keine Kategorien angegeben sind. Sobald bei excel2moodle die Fragen kategorisiert exportiert werden, sind die Kategorien enthalten. Wenn diese Kategorien im Moodle-Test bereits existieren, werden die Fragen in die existierenden Kategorien sortiert. Ansonsten werden die Kategorien angelegt.

moodle_pi utern